@@ -71,6 +71,7 @@ func TestLoadIacDir(t *testing.T) {
 		armv1   ARMV1
 		name    string
 		dirPath string
+		options map[string]interface{}
 	}{
 		{
 			name:    "empty config",
@@ -94,7 +95,7 @@ func TestLoadIacDir(t *testing.T) {
 
 	for _, tt := range table {
 		t.Run(tt.name, func(t *testing.T) {
-			aRC, gotErr := tt.armv1.LoadIacDir(tt.dirPath, false)
+			aRC, gotErr := tt.armv1.LoadIacDir(tt.dirPath, tt.options)
 			me, ok := gotErr.(*multierror.Error)
 			if !ok {
 				t.Errorf("expected multierror.Error, got %T", gotErr)
@@ -127,6 +128,8 @@ func TestARMMapper(t *testing.T) {
 		t.Error(err)
 	}
 
+	options := make(map[string]interface{})
+
 	armv1 := ARMV1{}
 
 	// get output json to verify
@@ -143,7 +146,7 @@ func TestARMMapper(t *testing.T) {
 
 	t.Run(root, func(t *testing.T) {
 
-		allResourceConfigs, gotErr := armv1.LoadIacDir(root, false)
+		allResourceConfigs, gotErr := armv1.LoadIacDir(root, options)
 		_, ok := gotErr.(*multierror.Error)
 		if !ok {
 			t.Errorf("expected multierror.Error, got %T", gotErr)
