@@ -51,11 +51,12 @@ type PassedRule struct {
 
 // ViolationStore Storage area for violation data
 type ViolationStore struct {
-	DirScanErrors     []DirScanErr  `json:"scan_errors,omitempty" yaml:"scan_errors,omitempty" xml:"scan_errors>scan_error,omitempty"`
-	PassedRules       []*PassedRule `json:"passed_rules,omitempty" yaml:"passed_rules,omitempty" xml:"passed_rules>passed_rule,omitempty"`
-	Violations        []*Violation  `json:"violations" yaml:"violations" xml:"violations>violation"`
-	SkippedViolations []*Violation  `json:"skipped_violations" yaml:"skipped_violations" xml:"skipped_violations>violation"`
-	Summary           ScanSummary   `json:"scan_summary" yaml:"scan_summary" xml:"scan_summary"`
+	DirScanErrors     []DirScanErr     `json:"scan_errors,omitempty" yaml:"scan_errors,omitempty" xml:"scan_errors>scan_error,omitempty"`
+	PassedRules       []*PassedRule    `json:"passed_rules,omitempty" yaml:"passed_rules,omitempty" xml:"passed_rules>passed_rule,omitempty"`
+	Violations        []*Violation     `json:"violations" yaml:"violations" xml:"violations>violation"`
+	SkippedViolations []*Violation     `json:"skipped_violations" yaml:"skipped_violations" xml:"skipped_violations>violation"`
+	Vulnerabilities   []*Vulnerability `json:"vulnerabilities,omitempty" yaml:"vulnerabilities,omitempty"`
+	Summary           ScanSummary      `json:"scan_summary" yaml:"scan_summary" xml:"scan_summary"`
 }
 
 // ScanSummary will hold the default scan summary data
@@ -66,6 +67,7 @@ type ScanSummary struct {
 	ShowViolationDetails bool   `json:"-" yaml:"-" xml:"-"`
 	TotalPolicies        int    `json:"policies_validated" yaml:"policies_validated" xml:"policies_validated,attr"`
 	ViolatedPolicies     int    `json:"violated_policies" yaml:"violated_policies" xml:"violated_policies,attr"`
+	Vulnerabilities      *int   `json:"vulnerabilities,omitempty" yaml:"vulnerabilities,omitempty"`
 	LowCount             int    `json:"low" yaml:"low" xml:"low,attr"`
 	MediumCount          int    `json:"medium" yaml:"medium" xml:"medium,attr"`
 	HighCount            int    `json:"high" yaml:"high" xml:"high,attr"`
@@ -73,6 +75,31 @@ type ScanSummary struct {
 	TotalTime int64 `json:"-" yaml:"-" xml:"-"`
 }
 
+// CVSS will hold cvss score details
+type CVSS struct {
+	V2Vector string  `json:"v2_vector,omitempty" yaml:"v2_vector,omitempty" xml:"v2_vector,attr,omitempty"`
+	V3Vector string  `json:"v3_vector,omitempty" yaml:"v3_vector,omitempty" xml:"v3_vector,attr,omitempty"`
+	V2Score  float64 `json:"v2_score,omitempty" yaml:"v2_score,omitempty" xml:"v2_score,attr,omitempty"`
+	V3Score  float64 `json:"v3_score,omitempty" yaml:"v3_score,omitempty" xml:"v3_score,attr,omitempty"`
+}
+
+//Vulnerability will hold vulnerability details that will be displayed in scan summary
+type Vulnerability struct {
+	Image            string `json:"image" yaml:"image"`
+	Container        string `json:"container,omitempty" yaml:"container,omitempty" xml:"container,attr"`
+	Package          string `json:"package,omitempty" yaml:"package,omitempty" xml:"package,attr"`
+	Severity         string `json:"severity" yaml:"severity" xml:"severity,attr"`
+	CVSSScore        CVSS   `json:"cvss_score,omitempty" yaml:"cvss_score,omitempty" xml:"cvss_score>cvss_score,omitempty"`
+	InstalledVersion string `json:"installed_version,omitempty" yaml:"installed_version,omitempty" xml:"installed_version,attr,omitempty"`
+	Description      string `json:"description,omitempty" yaml:"description,omitempty" xml:"description,attr,omitempty"`
+	VulnerabilityID  string `json:"vulnerability_id" yaml:"vulnerability_id" xml:"vulnerability_id,attr"`
+	File             string `json:"file,omitempty" yaml:"file,omitempty" xml:"file,attr,omitempty"`
+	LineNumber       int    `json:"line,omitempty" yaml:"line,omitempty" xml:"line,attr,omitempty"`
+	PrimaryURL       string `json:"primary_url,omitempty" yaml:"primary_url,omitempty" xml:"primary_url,attr,omitempty"`
+	ResourceName     string `json:"resource_name" yaml:"resource_name" xml:"resource_name,attr"`
+	ResourceType     string `json:"resource_type" yaml:"resource_type" xml:"resource_type,attr"`
+}
+
 // DirScanErr holds details for an error that occurred while iac providers scans a directory
 type DirScanErr struct {
 	IacType    string `json:"iac_type" yaml:"iac_type" xml:"iac_type,attr"`
