@@ -6,6 +6,6 @@ set -o pipefail
 
 GIT_COMMIT=$(git rev-parse --short HEAD 2>/dev/null)
 DOCKER_REPO="accurics/terrascan_atlantis"
-DIR="./atlantis"
+DIR="./integrations/atlantis"
 
 docker build -t ${DOCKER_REPO}:${GIT_COMMIT} ${DIR}
